sqlite: An SQL database engine
==============================

Description
-----------

SQLite is a software library that implements a self-contained,
serverless, zero-configuration, transactional SQL database engine.

License
-------

Public Domain


Upstream contact
----------------

-  https://www.sqlite.org

Dependencies
------------

-  readline


Special Update/Build Instructions
---------------------------------

-  Use the autoconf version of sqlite.
